@@ -1550,6 +1550,15 @@ ip_plugin_init()
     return;
 }
 
+void
+prime()
+{
+    struct in_addr	ip_zeros = { 0 };
+
+    /* initialize multicast route */
+    set_router(ip_zeros, NULL, FALSE);
+}
+
 void
 load(CFBundleRef bundle, Boolean bundleVerbose)
 {
